@@ -3,6 +3,7 @@
 
   SPDX-FileCopyrightText: 2007-2009 Nick Shaforostoff <shafff@ukr.net>
   SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2023 Łukasz Wojniłowicz <lukasz.wojnilowicz@gmail.com>
 
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -57,6 +58,12 @@ public:
     {
         return !m_path.isEmpty();
     }
+
+    bool isSourceFilePathsReady() const
+    {
+      return m_sourceFilePathsReady;
+    }
+
     ProjectModel* model();
 
     //void setPath(const QString& p){m_path=p;}
